# Code of Conduct

## Our Pledge

We as members, contributors, and maintainers pledge to make participation in the Pedre
community a harassment-free experience for everyone, regardless of age, body size,
visible or invisible disability, ethnicity, sex characteristics, gender identity and
expression, level of experience, education, socio-economic status, nationality, personal
appearance, race, religion, or sexual identity and orientation.

We pledge to act and interact in ways that contribute to an open, welcoming, diverse,
inclusive, and healthy community.

## Our Standards

Examples of behavior that contributes to a positive environment include:

- Being respectful and considerate in language and actions
- Giving and gracefully accepting constructive feedback
- Focusing on what is best for the community
- Showing empathy towards other community members

Examples of unacceptable behavior include:

- Harassment, discrimination, or exclusionary behavior
- Personal attacks, insults, or derogatory comments
- Trolling, flaming, or deliberately disruptive behavior
- Publishing others’ private information without permission

## Enforcement Responsibilities

Project maintainers are responsible for clarifying and enforcing our standards and will
take appropriate and fair corrective action in response to any behavior they deem
inappropriate, threatening, offensive, or harmful.

## Scope

This Code of Conduct applies within all community spaces, including issues, pull requests,
discussions, and other interactions related to the project.

## Enforcement

Instances of abusive, harassing, or otherwise unacceptable behavior may be reported to
the project maintainer.

All complaints will be reviewed and investigated promptly and fairly.

## Attribution

This Code of Conduct is adapted from the Contributor Covenant, version 2.1:
https://www.contributor-covenant.org/version/2/1/code_of_conduct.html
